;; Generated package description from mastodon.el  -*- mode: lisp-data; no-byte-compile: t; lexical-binding:t -*-
(define-package "mastodon" "2.0.17.0.20260509.74935" "Client for fediverse services using the Mastodon API" '((emacs "29.1") (persist "0.8") (tp "0.8")) :commit "4b30b2d96625e23325ff3727daa30969b6fe2eed" :authors '(("Johnson Denen" . "johnson.denen@gmail.com") ("Marty Hiatt" . "martianh@disroot.org")) :maintainer '("Marty Hiatt" . "martianh@disroot.org") :url "https://codeberg.org/martianh/mastodon.el")
